import axios from 'axios'
import { ElMessage } from 'element-plus'
import router from '../router'
import { API_BASE_URL } from '../config/api.config'

// 创建一个全局的指纹变量
let globalFingerprint = null

const request = axios.create({
  baseURL: API_BASE_URL,
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json'
  }
})

// 请求拦截器
request.interceptors.request.use(
  config => {
    // 如果有全局指纹，直接使用
    if (globalFingerprint) {
      config.headers['X-Device-Fingerprint'] = globalFingerprint
    }

    // 如果是访客页面的请求，不需要添加 token
    if (!config.url.startsWith('/visitor')) {
      const token = localStorage.getItem('token')
      if (token) {
        const tokenData = JSON.parse(token)
        config.headers.Authorization = `Bearer ${tokenData.token}`
      }
    }
    return config
  },
  error => {
    return Promise.reject(error)
  }
)

// 响应拦截器
request.interceptors.response.use(
  response => {
    const { data } = response
    console.log('Response Data:', data)
    
    // 登录接口特殊处理
    if (response.config.url === '/user/login') {
      if (data.retcode === 0) {
        localStorage.setItem('isAuthenticated', 'true')
      }
      return data
    }
    
    if (data.retcode === 0) {
      return data
    }

    // 显示错误消息
    ElMessage.error(data.message || '操作失败')
    return Promise.reject(new Error(data.message || '操作失败'))
  },
  error => {
    console.error('Request Error:', error)
    
    if (error.response) {
      switch (error.response.status) {
        case 401:
          // 清除所有认证相关的存储
          localStorage.removeItem('token')
          localStorage.removeItem('isAuthenticated')
          localStorage.removeItem('userRole')
          localStorage.removeItem('userInfo')
          
          // 只有非访客页面才需要跳转
          if (!router.currentRoute.value.path.startsWith('/visitor')) {
            router.push('/login')
          }
          break
        case 403:
          ElMessage.error('没有权限访问')
          break
        default:
          ElMessage.error(error.response.data?.message || '请求失败')
      }
    } else if (error.request) {
      ElMessage.error('服务器无响应，请检查后端服务是否启动')
    } else {
      ElMessage.error('请求配置错误')
    }
    return Promise.reject(error)
  }
)

// 导出一个设置指纹的方法
export const setGlobalFingerprint = (fingerprint) => {
  globalFingerprint = fingerprint
}

export default request 