import { createRouter, createWebHistory } from 'vue-router'
import { ElMessage } from 'element-plus'
import Layout from '../layout/Layout.vue'
import { UserAPI } from '../api/user'
import { ADMIN_ROUTE_BASE } from '@/config/api.config'
import { UserMask, hasPermission } from '@/utils/permission'

const routes = [
  {
    path: '/',
    redirect: '/visitor'
  },
  {
    path: '/login',
    name: 'Login',
    component: () => import('../views/LoginView.vue')
  },
  {
    path: '/register',
    name: 'Register',
    component: () => import('../views/RegisterView.vue')
  },
  {
    path: ADMIN_ROUTE_BASE,
    component: Layout,
    redirect: `${ADMIN_ROUTE_BASE}/dashboard`,
    children: [
      {
        path: 'dashboard',
        name: 'Dashboard',
        component: () => import('../views/Dashboard.vue'),
        meta: { 
          minMask: UserMask.Admin  // 管理员及以上权限可访问
        }
      },
      {
        path: 'tasks',
        name: 'Tasks',
        component: () => import('../views/TaskManagement.vue'),
        meta: { 
          minMask: UserMask.Admin  // 管理员及以上权限可访问
        }
      },
      {
        path: 'config',
        name: 'Config',
        component: () => import('../views/ConfigView.vue'),
        meta: { 
          minMask: UserMask.Admin  // 管理员及以上权限可访问
        }
      },
      {
        path: 'users',
        name: 'Users',
        component: () => import('../views/UserManagement.vue'),
        meta: { 
          minMask: UserMask.SuperAdmin  // 仅超级管理员可访问
        }
      },
      {
        path: 'profile',
        name: 'Profile',
        component: () => import('../views/UserProfile.vue'),
        meta: { roles: ['admin', 'guest'] }
      },
      {
        path: 'events',
        name: 'Events',
        component: () => import('../views/UserEvents.vue'),
        meta: { roles: ['admin', 'guest'] }
      },
      {
        path: 'debug',
        name: 'Debug',
        component: () => import('../views/DebugView.vue'),
        meta: { 
          minMask: UserMask.SuperAdmin  // 仅超级管理员可访问
        }
      }
    ]
  },
  {
    path: '/visitor',
    component: () => import('../layout/VisitorLayout.vue'),
    children: [
      {
        path: '',
        name: 'VisitorDownload',
        component: () => import('../views/visitor/DownloadPage.vue'),
        meta: { 
          public: true,
          title: 'iFileProxy - 文件代理下载'
        }
      },
      {
        path: 'tasks',
        name: 'VisitorTasks',
        component: () => import('../views/visitor/TaskList.vue'),
        meta: { 
          public: true,
          title: 'iFileProxy - 任务列表'
        }
      },
      {
        path: 'delete',
        name: 'VisitorDelete',
        component: () => import('../views/visitor/DeleteInfo.vue'),
        meta: { 
          public: true,
          title: 'iFileProxy - 删除访客信息'
        }
      }
    ]
  },
  {
    path: '/:pathMatch(.*)*',
    redirect: '/visitor'
  }
]

const router = createRouter({
  history: createWebHistory(),
  routes
})

// 简化路由守卫
router.beforeEach(async (to, from, next) => {
  // 如果是访客页面，直接放行
  if (to.path.startsWith('/visitor')) {
    next()
    return
  }

  // 如果是登录页和注册页可以直接访问
  if (to.path === '/login' || to.path === '/register') {
    const isAuthenticated = localStorage.getItem('isAuthenticated')
    if (isAuthenticated) {
      next('/admin/dashboard')
    } else {
      next()
    }
    return
  }

  // 如果是管理后台页面
  if (to.path.startsWith(ADMIN_ROUTE_BASE)) {
    const token = localStorage.getItem('token')
    const isAuthenticated = localStorage.getItem('isAuthenticated')
    const userInfo = JSON.parse(localStorage.getItem('userInfo'))
    
    if (!isAuthenticated || !token || !userInfo) {
      next('/login')
      return
    }

    // 检查权限
    if (to.meta.minMask !== undefined && !hasPermission(to.meta.minMask, userInfo.mask)) {
      ElMessage.error('没有访问权限')
      next('/admin/dashboard')
      return
    }

    next()
    return
  }

  // 其他未匹配的路由重定向到访客页面
  next('/visitor')
})

// 添加全局路由守卫来更新标题
router.afterEach((to) => {
  // 设置默认标题
  const defaultTitle = '后台管理系统'
  // 如果路由有title元信息，则使用它，否则使用默认标题
  document.title = to.meta.title || defaultTitle
})

export default router 